@@ -4,23 +4,17 @@ import traceback
 from pathlib import Path
 
 import click
-from git import Repo
-from git.cmd import GitCommandError
 from tqdm import tqdm
 
 import openpecha
 from openpecha import config
 from openpecha.alignment.tmx import create_opf as alignment
 from openpecha.blupdate import PechaBaseUpdate
-from openpecha.catalog import config as catalog_config
-from openpecha.catalog.filter import is_text_good_quality
-from openpecha.catalog.storage import GithubBucket
 from openpecha.core.pecha import OpenPechaFS
 from openpecha.corpus.quality import NonWordsCounter
-from openpecha.exceptions import PechaNotFound
-from openpecha.formatters import GoogleOCRFormatter, HFMLFormatter
+from openpecha.formatters import GoogleVisionFormatter, HFMLFormatter
 from openpecha.serializers import EpubSerializer, HFMLSerializer
-from openpecha.storages import GithubStorage, setup_auth_for_old_repo
+from openpecha.utils import download_pecha as download_pecha_util
 
 OP_PATH = config.BASE_PATH
 config = {
@@ -49,91 +43,65 @@ def cli():
     pass
 
 
-def create_config_dirs():
-    config["OP_DATA_PATH"].mkdir(parents=True, exist_ok=True)
-    config["CONFIG_PATH"].mkdir(parents=True, exist_ok=True)
-
-
-def _eval_branch(repo, branch):
-    """return default branch as fallback branch."""
-    if branch in repo.refs or f"origin/{branch}" in repo.refs:
-        return branch
-    elif "main" in repo.refs:
-        return "main"
-    else:
-        return "master"
-
-
-def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
-    # clone the repo
-    pecha_url = f"{config['OP_ORG']}/{pecha_id}.git"
-    if out_path:
-        out_path = Path(out_path)
-        out_path.mkdir(exist_ok=True, parents=True)
-        pecha_path = out_path / pecha_id
-    else:
-        pecha_path = config["OP_PECHAS_PATH"] / pecha_id
-
-    if pecha_path.is_dir():  # if repo is already exits at local then try to pull
-        repo = Repo(str(pecha_path))
-        branch = _eval_branch(repo, branch)
-        repo.git.checkout(branch)
-        if needs_update:
-            click.echo(INFO.format(f"Updating {pecha_id} ..."))
-            repo.git.pull("origin", branch)
-    else:
-        click.echo(INFO.format(f"Downloading {pecha_id} ..."))
-        try:
-            Repo.clone_from(pecha_url, str(pecha_path))
-        except GitCommandError:
-            raise PechaNotFound(f"Pecha with id {pecha_id} doesn't exist")
-        repo = Repo(str(pecha_path))
-        branch = _eval_branch(repo, branch)
-        repo.git.checkout(branch)
-
-    # setup auth
-    storage = GithubStorage()
-    setup_auth_for_old_repo(repo, org=storage.org_name, token=storage.token)
-
-    return pecha_path
-
-
-# Poti Download command
 @cli.command()
-@click.option("--number", "-n", help="Pecha number of pecha, for single pecha download")
-@click.option(
-    "--batch",
-    "-b",
-    help="path to text file containg list of names of \
-                                     pecha in separate line. Poti batch download",
-)
-@click.option(
-    "--filter",
-    "-f",
-    help="filter pecha by layer availability, specify \
-                                     layer names in comma separated, eg: title,yigchung,..",
-)
-@click.option("--out", "-o", help="directory to store all the pecha")
-def download(**kwargs):
+@click.argument("pecha_id")
+@click.option("--out", "-o", help="Directory to save the pecha")
+@click.option("--branch", "-b", help="Which branch to download, default is `main`")
+def download_pecha(**kwargs):
     """
-    Command to download pecha.
-    If id and batch options are not provided then it will download all the pecha.
+    Download a single pecha.
     """
-    pecha_id = get_pecha_id(kwargs["number"])
+    pecha_id = kwargs["pecha_id"]
+    output_path = kwargs["out"]
+    branch = kwargs["branch"]
 
-    # create config dirs
-    create_config_dirs()
+    click.echo(f"✨ Downloading {pecha_id}️...")
 
-    # get pecha
-    pechas = [pecha_id]
+    try:
+        pecha_path = download_pecha_util(pecha_id, out_path=output_path, branch=branch)
+    except Exception as e:
+        click.echo(f"❌ Failed to download {pecha_id}...x")
+        click.echo(f"❌ {e}")
+        return
 
-    # download the repo
-    for pecha in tqdm(pechas):
-        download_pecha(pecha, kwargs["out"])
+    click.echo(f"✅ Download completed")
+    click.echo(f"📖 Pecha saved at {pecha_path.resolve()}")
 
-    # print location of data
-    msg = f"Downloaded {pecha_id} ... ok"
-    click.echo(INFO.format(msg))
+
+@cli.command()
+@click.argument("batch_file_path")
+@click.option("--out", "-o", help="Directory to save the pecha")
+@click.option("--branch", "-b", help="Which branch to download, default is `main`")
+def download_pecha_batch(**kwargs):
+    """
+    Download a batch of pechas.
+    """
+    batch_file_path = Path(kwargs["batch_file_path"])
+    output_path = kwargs["out"]
+    branch = kwargs["branch"]
+
+    assert batch_file_path.is_file()
+
+    # resolve outpout path
+    output_path = output_path if output_path else (Path.cwd() / batch_file_path.stem)
+    output_path = Path(output_path).resolve()
+    output_path.mkdir(exist_ok=True, parents=True)
+
+    click.echo(f"✨ Downloading  the batch {batch_file_path.name}...")
+
+    for pecha_id in tqdm(batch_file_path.read_text().splitlines()):
+        if not pecha_id:
+            continue
+
+        try:
+            download_pecha_util(pecha_id, out_path=output_path, branch=branch)
+        except Exception as e:
+            click.echo(f"❌ Failed to download {pecha_id}...x")
+            click.echo("❌ Error: {e}")
+            continue
+
+    click.echo(f"✅ Download completed")
+    click.echo(f"📚 Batch saved at {output_path}")
 
 
 # OpenPecha Formatter
@@ -147,12 +115,12 @@ formatter_types = ["ocr", "hfml(default)", "tsadra"]
 @click.option("--id", "-i", type=int, help="Id of the pecha")
 @click.option("--output_path", "-o", help="output path to store opf pechas")
 @click.argument("input_path")
-def format(**kwargs):
+def import_text(**kwargs):
     """
-    Command to format pecha into opf
+    Import text from a file to OpenPecha format.
     """
     if kwargs["name"] == "ocr":
-        formatter = GoogleOCRFormatter(kwargs["output_path"])
+        formatter = GoogleVisionFormatter(kwargs["output_path"])
     elif kwargs["name"] == "tsadra":
         formatter = HFMLFormatter(kwargs["output_path"])
     else:
@@ -160,6 +128,7 @@ def format(**kwargs):
 
     formatter.create_opf(kwargs["input_path"], kwargs["id"])
 
+
 export_types = ["hfml(default)", "epub"]
 
 
@@ -169,9 +138,9 @@ export_types = ["hfml(default)", "epub"]
 )
 @click.option("--opf_path", "-op")
 @click.option("--output_path", "-o")
-def export(**kwargs):
+def export_text(**kwargs):
     """
-    Command to export Pecha in epub
+    Export text from OpenPecha format to a specified file format.
     """
 
     opf_path = kwargs["opf_path"]
@@ -186,70 +155,6 @@ def export(**kwargs):
     serializer.serialize(output_path)
 
 
-def _get_bucket(bucket_type, bucket_name, n):
-    if bucket_type == "github":
-        catalog_config.GITHUB_BUCKET_CONFIG["catalog"]["end"] = n
-        return GithubBucket(bucket_name, config=catalog_config.GITHUB_BUCKET_CONFIG)
-
-
-def _get_filter_strategy_caller(filter_strategy):
-    if filter_strategy == "non_words_ratio":
-        try:
-            from bonltk.text_quality import non_words_ratio
-        except Exception:
-            msg = (
-                "bonltk not installed. Install it with `pip install bonltk` "
-                "or from https://github.com/10zinten/bonltk"
-            )
-            raise ImportError(msg)
-        return non_words_ratio
-
-
-def _save_text(text, output_path, parent_path, fn):
-    pecha_path = Path(output_path) / parent_path
-    pecha_path.mkdir(exist_ok=True)
-    vol_path = pecha_path / fn
-    vol_path.write_text(text)
-
-
-@cli.command()
-@click.option("--output_path", "-o", type=click.Path(exists=True), required=True)
-@click.option("--bucket_type", "-bt", type=click.Choice(["github"]), default="github")
-@click.option("--bucket_name", "-bn", type=str, default="OpenPecha-Data")
-@click.option(
-    "--filter_strategy",
-    "-fs",
-    type=click.Choice(["non_words_ratio"]),
-    default="non_words_ratio",
-)
-@click.option(
-    "--threshold",
-    "-th",
-    type=float,
-    default=0.8,
-    help="Determines the quality of the text (1 being the highest and 0 being the lowest)",
-)
-@click.option("-n", type=int, default=1, help="number of pechas to download")
-@click.option("--verbose", "-v", help="verbose", is_flag=True)
-@click.option("--debug", "-d", help="debug", is_flag=True)
-def corpus_download(
-    output_path, bucket_type, bucket_name, filter_strategy, threshold, n, verbose, debug
-):
-    if debug:
-        logging.basicConfig(level=logging.DEBUG)
-    elif verbose:
-        logging.basicConfig(level=logging.INFO)
-
-    bucket = _get_bucket(bucket_type, bucket_name, n)
-    filter_strategy_caller = _get_filter_strategy_caller(filter_strategy)
-    for pecha_id, base in bucket.get_all_pechas_base():
-        for vol_base, vol_fn in base:
-            if is_text_good_quality(
-                vol_base, strategy=filter_strategy_caller, threshold=threshold
-            ):
-                _save_text(vol_base, output_path, pecha_id, vol_fn)
-
-
 @cli.command()
 @click.argument("pecha_number")
 @click.argument("pecha_path")
@@ -258,7 +163,7 @@ def update_layers(**kwargs):
     Update all the layers when base has been updated.
     """
     pecha_id = get_pecha_id(kwargs["pecha_number"])
-    src_pecha_path = download_pecha(pecha_id)
+    src_pecha_path = download_pecha_util(pecha_id)
 
     click.echo(INFO.format(f"Updating base of {pecha_id} ..."))
     src_opf_path = src_pecha_path / f"{pecha_id}.opf"
