@@ -3,9 +3,8 @@ from pathlib import Path
 
 import yaml
 
-from openpecha.formatters.layers import AnnType
-
-from .serialize import Serialize
+from openpecha.core.layer import LayerEnum
+from openpecha.serializers.serialize import Serialize
 
 
 class PedurmaSerializer(Serialize):
@@ -52,8 +51,8 @@ class PedurmaSerializer(Serialize):
         end_payload = ")"
         side = "ab"
         local_id = self.get_local_id(ann, uuid2localid)
-        ann_type = AnnType(ann["type"])
-        if ann_type == AnnType.pagination:
+        ann_type = LayerEnum(ann["type"])
+        if ann_type == LayerEnum.pagination:
             pg_idx = ann.get("page_index", "")
             if not pg_idx:
                 pg_idx = ann.get("imgnum", "")
@@ -77,7 +76,7 @@ class PedurmaSerializer(Serialize):
             else:
                 start_payload += "\n"
             only_start_ann = True
-        elif ann_type == AnnType.pedurma_note:
+        elif ann_type == LayerEnum.pedurma_note:
             start_payload = ""
             end_payload = f'{ann["collation_note"]}'
 
